# qfi

[![Release](https://img.shields.io/github/v/release/ggianfran/qfi)](https://img.shields.io/github/v/release/ggianfran/qfi)
[![Build status](https://img.shields.io/github/actions/workflow/status/ggianfran/qfi/main.yml?branch=main)](https://github.com/ggianfran/qfi/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/ggianfran/qfi)](https://img.shields.io/github/commit-activity/m/ggianfran/qfi)
[![License](https://img.shields.io/github/license/ggianfran/qfi)](https://img.shields.io/github/license/ggianfran/qfi)

Quantitative Finance Toolkit
